@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import OrderStatusType, PaymentOptionType
 
@@ -59,7 +59,7 @@ _RequiredCreateOrderInputRequestTypeDef = TypedDict(
     "_RequiredCreateOrderInputRequestTypeDef",
     {
         "OutpostIdentifier": str,
-        "LineItems": List["LineItemRequestTypeDef"],
+        "LineItems": Sequence["LineItemRequestTypeDef"],
         "PaymentOption": PaymentOptionType,
     },
 )
@@ -99,7 +99,7 @@ _OptionalCreateOutpostInputRequestTypeDef = TypedDict(
         "Description": str,
         "AvailabilityZone": str,
         "AvailabilityZoneId": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -215,9 +215,9 @@ ListOutpostsInputRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "LifeCycleStatusFilter": List[str],
-        "AvailabilityZoneFilter": List[str],
-        "AvailabilityZoneIdFilter": List[str],
+        "LifeCycleStatusFilter": Sequence[str],
+        "AvailabilityZoneFilter": Sequence[str],
+        "AvailabilityZoneIdFilter": Sequence[str],
     },
     total=False,
 )
@@ -324,7 +324,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -332,6 +332,6 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
